@@ -1,4 +1,4 @@
-from pydantic import Field, BaseModel
+from pydantic import Field
 from docarray.base_doc.doc import BaseDocWithoutId
 
 
