@@ -1,4 +1,4 @@
-from typing import List, Optional, Union
+from typing import Dict, List, Optional, Union
 
 from docarray import BaseDoc, DocList
 from docarray.base_doc.doc import BaseDocWithoutId
@@ -135,6 +135,7 @@ class ClassificationInput(BaseDocWithoutId):
         description='The identifier of the model.\n'
         '\nAvailable models and corresponding param size and dimension:\n'
         '- `jina-clip-v1`,\t223M,\t768\n'
+        '- `jina-clip-v2`,\t865M,\t1024\n'
         '- `jina-embeddings-v2-base-en`,\t137M,\t768\n'
         '- `jina-embeddings-v2-base-es`,\t161M,\t768\n'
         '- `jina-embeddings-v2-base-de`,\t161M,\t768\n'
@@ -151,8 +152,8 @@ class ClassificationInput(BaseDocWithoutId):
     input: Union[List[Union[TextDoc, ImageDoc, str]], TextDoc, ImageDoc, str] = Field(
         description='List of text and images or a single text and image for classification',  # noqa
     )
-    labels: Optional[List[str]] = Field(
-        description='List of labels used for classification'
+    labels: Optional[Union[List[str], Dict[str, List[str]]]] = Field(
+        description='List of labels or a dictionary of structured labels for zero-shot classification',  # noqa
     )
 
     @classmethod
@@ -182,15 +183,24 @@ class ClassificationInput(BaseDocWithoutId):
         arbitrary_types_allowed = True
         schema_extra = {
             "example": {
-                "classifier_id": "classifier_id",
+                "model": "jina-embeddings-v3",
                 "input": [
                     {"text": "text1"},
                     {"text": "text2"},
+                    {"text": "text3"},
                 ],
+                "labels": ["label1", "label2", "label3"],
             }
         }
 
 
+class ClassificationLabelScore(BaseDocWithoutId):
+    label: str = Field(description='The label of the classification output')
+    score: float = Field(
+        description='The confidence score of the classification output'
+    )
+
+
 class ClassificationObject(BaseDocWithoutId):
     """Classification object"""
 
@@ -198,18 +208,28 @@ class ClassificationObject(BaseDocWithoutId):
     index: int = Field(
         description='The index of the classification output, corresponding to the index in the list of inputs'  # noqa
     )
-    prediction: Union[str] = Field(description='The label with the highest probability')
-    score: float = Field(
+    prediction: Union[str, Dict[str, str]] = Field(
+        description='The label with the highest probability'
+    )
+    score: Union[float, Dict[str, float]] = Field(
         description='The confidence score of the classification output'
     )
+    predictions: Union[
+        List[ClassificationLabelScore], Dict[str, List[ClassificationLabelScore]]
+    ] = Field(description='List of labels and their scores')
 
     class Config(BaseDocWithoutId.Config):
         allow_population_by_field_name = True
         arbitrary_types_allowed = True
         schema_extra = {
             "example": {
-                "prediction": "label1",
                 "object": "classification",
+                "prediction": "label1",
+                "score": 0.75,
+                "predictions": [
+                    {"label": "label1", "score": 0.75},
+                    {"label": "label2", "score": 0.25},
+                ],
             }
         }
 
@@ -218,7 +238,6 @@ class Usage(BaseModel):
     total_tokens: int = Field(
         description='The number of tokens used by all the texts in the input'
     )
-    prompt_tokens: int = Field(description='Same as total_tokens')
 
 
 class ClassificationOutput(BaseDocWithoutId):
@@ -242,15 +261,23 @@ class ClassificationOutput(BaseDocWithoutId):
                         "prediction": "label1",
                         "object": "classification",
                         "score": 0.75,
+                        "predictions": [
+                            {"label": "label1", "score": 0.75},
+                            {"label": "label2", "score": 0.25},
+                        ],
                     },
                     {
                         "index": 1,
                         "prediction": "label2",
                         "object": "classification",
                         "score": 0.54,
+                        "predictions": [
+                            {"label": "label2", "score": 0.54},
+                            {"label": "label1", "score": 0.46},
+                        ],
                     },
                 ],
-                "usage": {"total_tokens": 15, "prompt_tokens": 15},
+                "usage": {"total_tokens": 15},
             }
         }
 
@@ -264,4 +291,7 @@ class ExecutorClassificationOutputDoc(BaseDoc):
     score: float = Field(
         description='The confidence score of the classification output'
     )
+    predictions: List[ClassificationLabelScore] = Field(
+        description='List of labels and their scores'
+    )
     usage: ExecutorUsage = Field(description='Total usage of the request')
