@@ -1,18 +1,17 @@
-from typing import List, Union, Literal, Optional, Dict
+from typing import Dict, List, Literal, Optional, Union
 
+from api_schemas.base import BaseInputModel
+from api_schemas.embedding import ExecutorUsage, TextDoc
 from docarray import BaseDoc, DocList
 from docarray.base_doc.doc import BaseDocWithoutId
 from docarray.typing import NdArray
-from pydantic import Field, validator
-
-from api_schemas.embedding import ExecutorUsage, TextDoc, Usage
-from api_schemas.base import BaseInputModel
+from pydantic import BaseModel, Field, validator
 
 
-## Model to be imported by the Executor and used by the Universal API to communicate with it
+## Model to be imported by the Executor and used by the Universal API to communicate with it # noqa
 class MultiEmbeddingsDoc(BaseDoc):
-    """Document to be returned by the embedding backend, containing the embedding vector and the token usage for the
-    corresponding input texts"""
+    """Document to be returned by the embedding backend, containing the embedding
+    vector and the token usage for the corresponding input texts"""
 
     embeddings: NdArray = Field(
         description='A tensor of embeddings for the text', default=[]
@@ -28,16 +27,16 @@ class MultiEmbeddingsObject(BaseDocWithoutId):
 
     object: str = 'embeddings'
     index: int = Field(
-        description='The index of the embedding output, corresponding to the index in the list of inputs'
+        description='The index of the embedding output, corresponding to the index in the list of inputs'  # noqa
     )
     embeddings: Union[
         List[bytes], NdArray, Dict[str, Union[List[bytes], NdArray]]
     ] = Field(
-        description='A tensor of embeddings for the text. It may come as the base64 encoded of the embeddings tensor '
-        'if "encoding_type" is "base64". It can be rebuilt in the client as `np.frombuffer('
-        'base64.b64decode(embeddings), dtype=np.float32)`. In case of multiple "encoding_type" are requested, '
-        'they will be returned in a '
-        'dictionary where the key is the encoding format.'
+        description='A tensor of embeddings for the text. It may come as the base64 '
+        'encoded of the embeddings tensor if "encoding_type" is "base64". It can be '
+        'rebuilt in the client as `np.frombuffer(base64.b64decode(embeddings), '
+        'dtype=np.float32)`. In case of multiple "encoding_type" are requested, '
+        'they will be returned in a dictionary where the key is the encoding format.'
     )
 
     # truncated: Optional[bool] = Field(
@@ -64,8 +63,8 @@ class LateInteractionInput(BaseDoc):
         description='The embeddings of all the documents to rerank'
     )
     top_n: Optional[int] = Field(
-        description='The number of most relevant documents or indices to return, defaults to '
-        'the length of `documents`'
+        description='The number of most relevant documents or indices to return, '
+        'defaults to the length of `documents`'
     )
 
 
@@ -73,19 +72,21 @@ class LateInteraction(BaseInputModel):
     """The input to the API for late interaction"""
 
     query_embeddings: Union[List[bytes], NdArray] = Field(
-        description='The embeddings of the query. It should be of the shape (num_tokens, token_embedding_size). It '
-        'can also be a base64 encoded string of the "float32" embeddings array. You can pass them as a list of base64 encoded '
-        'strings with `base64.b64encode(nparray.tobytes()).decode()`',
+        description='The embeddings of the query. It should be of the shape ('
+        'num_tokens, token_embedding_size). It can also be a base64 encoded string '
+        'of the "float32" embeddings array. You can pass them as a list of base64 '
+        'encoded strings with `base64.b64encode(nparray.tobytes()).decode()`',
     )
     documents_embeddings: List[Union[List[bytes], NdArray]] = Field(
-        description='The embeddings of all the documents to rerank. Each matrix in the list should be of the shape ('
-        'num_tokens, token_embedding_size). It can also be list of list of base64 encoded strings of the '
-        '"float32" embeddings. You can pass them as a '
-        'string with `base64.b64encode(nparray.tobytes()).decode()`'
+        description='The embeddings of all the documents to rerank. Each matrix in '
+        'the list should be of the shape (num_tokens, token_embedding_size). It can '
+        'also be list of list of base64 encoded strings of the "float32" embeddings. '
+        'You can pass them as a string with `base64.b64encode(nparray.tobytes())'
+        '.decode()`'
     )
     top_n: Optional[int] = Field(
-        description='The number of most relevant documents or indices to return, defaults to '
-        'the length of `documents`'
+        description='The number of most relevant documents or indices to return, '
+        'defaults to the length of `documents`'
     )
 
     @classmethod
@@ -144,8 +145,8 @@ class TextEmbeddingInput(BaseInputModel):
         ]
     ] = Field(
         description='The format in which you want the embeddings to be returned.'
-        'Possible value are `float`, `base64`, `binary`, `ubinary` or a list containing any of them. Defaults to '
-        '`float`',
+        'Possible value are `float`, `base64`, `binary`, `ubinary` or a list '
+        'containing any of them. Defaults to `float`',
         alias='embedding_type',
     )
 
@@ -156,7 +157,7 @@ class TextEmbeddingInput(BaseInputModel):
     )
 
     # truncate_input: Optional[bool] = Field(
-    #     description='Flag to determine if the text needs to be truncated when exceeding the maximum token length',
+    #     description='Flag to determine if the text needs to be truncated when exceeding the maximum token length', # noqa
     #     default=None,
     # )
 
@@ -183,6 +184,12 @@ class TextEmbeddingInput(BaseInputModel):
         }
 
 
+class Usage(BaseModel):
+    total_tokens: int = Field(
+        description='The number of tokens used by all the texts in the input'
+    )
+
+
 class ColbertModelEmbeddingsOutput(BaseInputModel):
     """Output of the embedding service"""
 
@@ -191,7 +198,7 @@ class ColbertModelEmbeddingsOutput(BaseInputModel):
         description='A list of Embedding Objects returned by the embedding service'
     )
     usage: Usage = Field(
-        description='Total usage of the request. Sums up the usage from each individual input'
+        description='Total usage of the request. Sums up the usage from each individual input'  # noqa
     )
 
     class Config(BaseInputModel.Config):
@@ -211,6 +218,6 @@ class ColbertModelEmbeddingsOutput(BaseInputModel):
                         "object": "embeddings",
                     },
                 ],
-                "usage": {"total_tokens": 15, "prompt_tokens": 15},
+                "usage": {"total_tokens": 15},
             }
         }
