@@ -1,7 +1,9 @@
 from typing import List, Optional, Union
 
 from api_schemas.base import BaseInputModel
+from api_schemas.image import ImageDoc, ImageDocWithoutId, TextOrImageDoc
 from docarray import BaseDoc, DocList
+from docarray.base_doc.any_doc import AnyDoc
 from docarray.base_doc.doc import BaseDocWithoutId
 from pydantic import BaseModel, Field, validator
 
@@ -26,7 +28,8 @@ class RankInput(BaseDoc):
     )
 
     documents: List[TextDoc] = Field(
-        description='A list of text documents or strings to rerank. If a document is provided the text fields is required and all other fields will be preserved in the response.',  # noqa
+        description='A list of text documents or strings to rerank. If a document is provided the text fields is required and all other fields will be preserved in the response.',
+        # noqa
     )
 
     top_n: Optional[int] = Field(
@@ -35,6 +38,56 @@ class RankInput(BaseDoc):
     )
 
 
+class MultiModalRankInput(BaseDoc):
+    query: TextOrImageDoc = Field(
+        description='The search query',
+    )
+
+    documents: List[Union[TextOrImageDoc]] = Field(
+        description='A list of text, image documents or strings to rerank. If a document is provided the text fields is required and all other fields will be preserved in the response.',
+        # noqa
+    )
+
+    top_n: Optional[int] = Field(
+        description='The number of most relevant documents or indices to return, defaults to '  # noqa
+        'the length of `documents`'
+    )
+
+
+class MultiModalRankedObjectOutput(BaseDoc):
+    """Ranked object"""
+
+    index: int = Field(description='The index of the result in the input documents')
+    document: Optional[TextOrImageDoc] = Field(description='The document returned')
+
+    relevance_score: float = Field(description='The relevance score')
+    usage: ExecutorUsage
+
+    class Config(BaseDocWithoutId.Config):
+        allow_population_by_field_name = True
+        arbitrary_types_allowed = True
+        schema_extra = {
+            "example": {
+                "index": 0,
+                "document": {"text": "Document text"},
+                "relevance_score": 0.9,
+            }
+        }
+
+
+class MultiModalRankOutput(BaseDoc):
+    query_usage: ExecutorUsage = Field(
+        description='The usage corresponding to the Query'
+    )
+    docs_usage: ExecutorUsage = Field(
+        description='The usage corresponding to all the Documents processed. It may differ with the sum of the results usages when `top_n` is provided in input'
+        # noqa
+    )
+    results: DocList[MultiModalRankedObjectOutput] = Field(
+        description='An ordered list of ranked documents'
+    )
+
+
 class RankedObjectOutput(BaseDoc):
     """Ranked object"""
 
@@ -61,7 +114,8 @@ class RankOutput(BaseDoc):
         description='The usage corresponding to the Query'
     )
     docs_usage: ExecutorUsage = Field(
-        description='The usage corresponding to all the Documents processed. It may differ with the sum of the results usages when `top_n` is provided in input'  # noqa
+        description='The usage corresponding to all the Documents processed. It may differ with the sum of the results usages when `top_n` is provided in input'
+        # noqa
     )
     results: DocList[RankedObjectOutput] = Field(
         description='An ordered list of ranked documents'
@@ -75,7 +129,7 @@ class TextDocWithoutId(BaseDocWithoutId):
     text: str
 
 
-class TextRankInput(BaseInputModel):
+class MixedRankInput(BaseInputModel):
     """The input to the API for text embedding. OpenAI compatible"""
 
     model: str = Field(
@@ -88,12 +142,13 @@ class TextRankInput(BaseInputModel):
         '- `jina-colbert-v1-en`,\t137M\n',
     )
 
-    query: Union[str, TextDoc] = Field(
+    query: Union[str, TextDoc, ImageDoc] = Field(
         description='The search query',
     )
 
-    documents: Union[List[str], List[TextDoc]] = Field(
-        description='A list of text documents or strings to rerank. If a document is provided the text fields is required and all other fields will be preserved in the response.',  # noqa
+    documents: List[Union[ImageDoc, TextDoc, str]] = Field(
+        description='A list of text documents, image documents or strings to rerank. If a document is provided the text or image fields are required and all other fields will be preserved in the response.',
+        # noqa
     )
 
     top_n: Optional[int] = Field(
@@ -137,7 +192,7 @@ class TextRankInput(BaseInputModel):
         arbitrary_types_allowed = True
         schema_extra = {
             "example": {
-                "model": "jina-reranker-v1-base-en",
+                "model": "jina-reranker-v2-base-multilingual",
                 "query": "Search query",
                 "documents": ["Document to rank 1", "Document to rank 2"],
             },
@@ -148,7 +203,9 @@ class RankedObject(BaseDocWithoutId):
     """Ranked object"""
 
     index: int = Field(description='The index of the result in the input documents')
-    document: Optional[TextDocWithoutId] = Field(description='The document returned')
+    document: Optional[Union[TextDocWithoutId, ImageDocWithoutId]] = Field(
+        description='The document returned'
+    )
 
     relevance_score: float = Field(description='The relevance score')
 
@@ -168,7 +225,6 @@ class Usage(BaseModel):
     total_tokens: int = Field(
         description='The number of tokens used by all the texts in the input'
     )
-    prompt_tokens: int = Field(description='Same as total_tokens')
 
     class Config(BaseModel.Config):
         allow_population_by_field_name = True
@@ -176,7 +232,6 @@ class Usage(BaseModel):
         schema_extra = {
             "example": {
                 "total_tokens": 15,
-                "prompt_tokens": 15,
             }
         }
 
