@@ -165,6 +165,7 @@ class TrainingInput(BaseDocWithoutId):
         description='The identifier of the model.\n'
         '\nAvailable models and corresponding param size and dimension:\n'
         '- `jina-clip-v1`,\t223M,\t768\n'
+        '- `jina-clip-v2`,\t865M,\t1024\n'
         '- `jina-embeddings-v2-base-en`,\t137M,\t768\n'
         '- `jina-embeddings-v2-base-es`,\t161M,\t768\n'
         '- `jina-embeddings-v2-base-de`,\t161M,\t768\n'
@@ -213,8 +214,8 @@ class TrainingInput(BaseDocWithoutId):
         arbitrary_types_allowed = True
         schema_extra = {
             "example": {
-                "model": "jina-embeddings-v2-base-en",
-                "access": "public",
+                "model": "jina-embeddings-v3",
+                "access": "private",
                 "input": [
                     {"text": "text1", "label": "label1"},
                     {"text": "text2", "label": "label2"},
@@ -229,7 +230,6 @@ class Usage(BaseModel):
     total_tokens: int = Field(
         description='The number of tokens used by all the texts in the input'
     )
-    prompt_tokens: int = Field(description='Same as total_tokens')
 
 
 class TrainingOutput(BaseDocWithoutId):
@@ -252,7 +252,7 @@ class TrainingOutput(BaseDocWithoutId):
             "example": {
                 "classifier_id": "classifier_id",
                 "num_samples": 10,
-                "usage": {"total_tokens": 15, "prompt_tokens": 15},
+                "usage": {"total_tokens": 15},
             }
         }
 
